@@ -25,6 +25,7 @@
 #include <glib.h>
 
 #include <libxml/HTMLparser.h>
+#include <libtracker-miners-common/tracker-file-utils.h>
 #include <libtracker-miners-common/tracker-utils.h>
 #include <libtracker-extract/tracker-extract.h>
 
@@ -234,10 +235,9 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 {
 	TrackerResource *metadata;
 	GFile *file;
-	TrackerConfig *config;
 	htmlDocPtr doc;
 	parser_data pd;
-	gchar *filename;
+	gchar *filename, *resource_uri;
 	xmlSAXHandler handler = {
 		NULL, /* internalSubset */
 		NULL, /* isStandalone */
@@ -275,8 +275,10 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 
 	file = tracker_extract_info_get_file (info);
 
-	metadata = tracker_resource_new (NULL);
+	resource_uri = tracker_file_get_content_identifier (file, NULL, NULL);
+	metadata = tracker_resource_new (resource_uri);
 	tracker_resource_add_uri (metadata, "rdf:type", "nfo:HtmlDocument");
+	g_free (resource_uri);
 
 	pd.metadata = metadata;
 	pd.current = -1;
@@ -284,8 +286,7 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 	pd.plain_text = g_string_new (NULL);
 	pd.title = g_string_new (NULL);
 
-	config = tracker_main_get_config ();
-	pd.n_bytes_remaining = tracker_config_get_max_bytes (config);
+	pd.n_bytes_remaining = tracker_extract_info_get_max_text (info);
 
 	filename = g_file_get_path (file);
 	doc = htmlSAXParseFile (filename, NULL, &handler, &pd);
