@@ -151,6 +151,10 @@ read_toc (PopplerIndexIter  *index,
 			case POPPLER_ACTION_RENDITION:
 			case POPPLER_ACTION_OCG_STATE:
 			case POPPLER_ACTION_JAVASCRIPT:
+			#if POPPLER_CHECK_VERSION (0, 90, 0)
+  			case POPPLER_ACTION_RESET_FORM:
+			#endif
+
 				/* Do nothing */
 				break;
 		}
@@ -281,7 +285,6 @@ G_MODULE_EXPORT gboolean
 tracker_extract_get_metadata (TrackerExtractInfo  *info,
                               GError             **error)
 {
-	TrackerConfig *config;
 	time_t creation_date;
 	GError *inner_error = NULL;
 	TrackerResource *metadata;
@@ -295,7 +298,7 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 	GPtrArray *keywords;
 	guint i;
 	GFile *file;
-	gchar *filename;
+	gchar *filename, *resource_uri;
 	int fd;
 	gchar *contents = NULL;
 	gsize len;
@@ -346,7 +349,9 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 
 	if (inner_error) {
 		if (inner_error->code == POPPLER_ERROR_ENCRYPTED) {
-			metadata = tracker_resource_new (NULL);
+			resource_uri = tracker_file_get_content_identifier (file, NULL, NULL);
+			metadata = tracker_resource_new (resource_uri);
+			g_free (resource_uri);
 
 			tracker_resource_add_uri (metadata, "rdf:type", "nfo:PaginatedTextDocument");
 			tracker_resource_set_boolean (metadata, "nfo:isContentEncrypted", TRUE);
@@ -377,8 +382,10 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 		return FALSE;
 	}
 
-	metadata = tracker_resource_new (NULL);
+	resource_uri = tracker_file_get_content_identifier (file, NULL, NULL);
+	metadata = tracker_resource_new (resource_uri);
 	tracker_resource_add_uri (metadata, "rdf:type", "nfo:PaginatedTextDocument");
+	g_free (resource_uri);
 
 	g_object_get (document,
 	              "title", &pd.title,
@@ -537,8 +544,7 @@ tracker_extract_get_metadata (TrackerExtractInfo  *info,
 
 	tracker_resource_set_int64 (metadata, "nfo:pageCount", poppler_document_get_n_pages(document));
 
-	config = tracker_main_get_config ();
-	n_bytes = tracker_config_get_max_bytes (config);
+	n_bytes = tracker_extract_info_get_max_text (info);
 	content = extract_content_text (document, n_bytes);
 
 	if (content) {
