@@ -21,13 +21,8 @@
 #ifndef __TRACKER_MAIN_H__
 #define __TRACKER_MAIN_H__
 
-#include "tracker-config.h"
-
 G_BEGIN_DECLS
 
-/* Enables getting the config object from extractors */
-TrackerConfig    *tracker_main_get_config         (void);
-
 G_END_DECLS
 
 #endif /* __TRACKER_MAIN_H__ */
