@@ -41,11 +41,8 @@ typedef struct {
 	GCancellable *cancellable;
 	GDBusMethodInvocation *invocation;
 	TrackerDBusRequest *request;
-	gchar *subject;
-	GPtrArray *results;
-	TrackerSparqlConnection *connection;
+	TrackerResource *resource;
 	GList *writeback_handlers;
-	guint cancel_id;
 	GError *error;
 } WritebackData;
 
@@ -53,8 +50,6 @@ typedef struct {
 	GMainContext *context;
 	GMainLoop *main_loop;
 
-	GVolumeMonitor *volume_monitor;
-
 	GDBusConnection *d_connection;
 	GDBusNodeInfo *introspection_data;
 	guint registration_id;
@@ -72,7 +67,6 @@ typedef struct {
 	guint initialized : 1;
 
 	GHashTable *modules;
-	TrackerSparqlConnection *connection;
 	WritebackData *current;
 } TrackerControllerPrivate;
 
@@ -83,16 +77,8 @@ typedef struct {
 static const gchar *introspection_xml =
 	"<node>"
 	"  <interface name='org.freedesktop.Tracker3.Writeback'>"
-	"    <method name='GetPid'>"
-	"      <arg type='i' name='value' direction='out' />"
-	"    </method>"
-	"    <method name='PerformWriteback'>"
-	"      <arg type='s' name='subject' direction='in' />"
-	"      <arg type='as' name='rdf_types' direction='in' />"
-	"      <arg type='aas' name='results' direction='in' />"
-	"    </method>"
-	"    <method name='CancelTasks'>"
-	"      <arg type='as' name='subjects' direction='in' />"
+	"    <method name='Writeback'>"
+	"      <arg type='a{sv}' name='rdf' direction='in' />"
 	"    </method>"
 	"  </interface>"
 	"</node>";
@@ -144,7 +130,6 @@ tracker_controller_finalize (GObject *object)
 
 	tracker_controller_dbus_stop (controller);
 
-	g_object_unref (priv->volume_monitor);
 	g_hash_table_unref (priv->modules);
 
 	g_main_loop_unref (priv->main_loop);
@@ -207,33 +192,10 @@ tracker_controller_class_init (TrackerControllerClass *klass)
 	                                                    G_PARAM_STATIC_STRINGS));
 }
 
-static void
-task_cancellable_cancelled_cb (GCancellable  *cancellable,
-                               WritebackData *data)
-{
-	TrackerControllerPrivate *priv;
-
-	priv = tracker_controller_get_instance_private (data->controller);
-
-	g_mutex_lock (&priv->mutex);
-
-	if (priv->current == data) {
-		g_message ("Cancelled writeback task for '%s' was currently being "
-		           "processed, _exit()ing immediately",
-		           data->subject);
-		_exit (0);
-	}
-
-	g_mutex_unlock (&priv->mutex);
-}
-
-
 static WritebackData *
 writeback_data_new (TrackerController       *controller,
                     GList                   *writeback_handlers,
-                    TrackerSparqlConnection *connection,
-                    const gchar             *subject,
-                    GPtrArray               *results,
+                    TrackerResource         *resource,
                     GDBusMethodInvocation   *invocation,
                     TrackerDBusRequest      *request)
 {
@@ -242,18 +204,12 @@ writeback_data_new (TrackerController       *controller,
 	data = g_slice_new (WritebackData);
 	data->cancellable = g_cancellable_new ();
 	data->controller = g_object_ref (controller);
-	data->subject = g_strdup (subject);
-	data->results = g_ptr_array_ref (results);
+	data->resource = g_object_ref (resource);
 	data->invocation = invocation;
-	data->connection = g_object_ref (connection);
 	data->writeback_handlers = writeback_handlers;
 	data->request = request;
 	data->error = NULL;
 
-	data->cancel_id = g_cancellable_connect (data->cancellable,
-	                                         G_CALLBACK (task_cancellable_cancelled_cb),
-	                                         data, NULL);
-
 	return data;
 }
 
@@ -263,11 +219,8 @@ writeback_data_free (WritebackData *data)
 	/* We rely on data->invocation being freed through
 	 * the g_dbus_method_invocation_return_* methods
 	 */
-	g_cancellable_disconnect (data->cancellable, data->cancel_id);
-	g_free (data->subject);
-	g_object_unref (data->connection);
-	g_ptr_array_unref (data->results);
 	g_object_unref (data->cancellable);
+	g_object_unref (data->resource);
 
 	g_list_foreach (data->writeback_handlers, (GFunc) g_object_unref, NULL);
 	g_list_free (data->writeback_handlers);
@@ -278,57 +231,6 @@ writeback_data_free (WritebackData *data)
 	g_slice_free (WritebackData, data);
 }
 
-static void
-cancel_tasks (TrackerController *controller,
-              const gchar       *subject,
-              GFile             *file)
-{
-	TrackerControllerPrivate *priv;
-	GList *elem;
-
-	priv = tracker_controller_get_instance_private (controller);
-
-	for (elem = priv->ongoing_tasks; elem; elem = elem->next) {
-		WritebackData *data = elem->data;
-
-		if (g_strcmp0 (subject, data->subject) == 0) {
-			g_message ("Cancelling not yet processed task ('%s')",
-			           data->subject);
-			g_cancellable_cancel (data->cancellable);
-		}
-
-		if (file) {
-			guint i;
-			for (i = 0; i < data->results->len; i++) {
-				GStrv row = g_ptr_array_index (data->results, i);
-				if (row[0] != NULL) {
-					GFile *task_file;
-					task_file = g_file_new_for_uri (row[0]);
-					if (g_file_equal (task_file, file) ||
-					    g_file_has_prefix (task_file, file)) {
-						/* Mount path contains some file being processed */
-						g_message ("Cancelling task ('%s')", row[0]);
-						g_cancellable_cancel (data->cancellable);
-					}
-					g_object_unref (task_file);
-				}
-			}
-		}
-	}
-}
-
-static void
-mount_point_removed_cb (GVolumeMonitor *monitor,
-                        GMount         *mount,
-                        gpointer        user_data)
-{
-	GFile *mount_file;
-
-	mount_file = g_mount_get_root (mount);
-	cancel_tasks (TRACKER_CONTROLLER (user_data), NULL, mount_file);
-	g_object_unref (mount_file);
-}
-
 static gboolean
 reset_shutdown_timeout_cb (gpointer user_data)
 {
@@ -386,39 +288,11 @@ tracker_controller_init (TrackerController *controller)
 	priv->context = g_main_context_new ();
 	priv->main_loop = g_main_loop_new (priv->context, FALSE);
 
-	priv->volume_monitor = g_volume_monitor_get ();
-	g_signal_connect_object (priv->volume_monitor, "mount-removed",
-	                         G_CALLBACK (mount_point_removed_cb), controller, 0);
-
 	g_cond_init (&priv->initialization_cond);
 	g_mutex_init (&priv->initialization_mutex);
 	g_mutex_init (&priv->mutex);
 }
 
-static void
-handle_method_call_get_pid (TrackerController     *controller,
-                            GDBusMethodInvocation *invocation,
-                            GVariant              *parameters)
-{
-	TrackerDBusRequest *request;
-	pid_t value;
-
-	request = tracker_g_dbus_request_begin (invocation,
-	                                        "%s()",
-	                                        __FUNCTION__);
-
-	reset_shutdown_timeout (controller);
-	value = getpid ();
-	tracker_dbus_request_debug (request,
-	                            "PID is %d",
-	                            value);
-
-	tracker_dbus_request_end (request, NULL);
-
-	g_dbus_method_invocation_return_value (invocation,
-	                                       g_variant_new ("(i)", (gint) value));
-}
-
 static gboolean
 perform_writeback_cb (gpointer user_data)
 {
@@ -446,25 +320,6 @@ perform_writeback_cb (gpointer user_data)
 	return FALSE;
 }
 
-static gboolean
-sparql_rdf_types_match (const gchar * const *module_types,
-                        const gchar * const *rdf_types)
-{
-	guint n;
-
-	for (n = 0; rdf_types[n] != NULL; n++) {
-		guint i;
-
-		for (i = 0; module_types[i] != NULL; i++) {
-			if (g_strcmp0 (module_types[i], rdf_types[n]) == 0) {
-				return TRUE;
-			}
-		}
-	}
-
-	return FALSE;
-}
-
 static void
 io_writeback_job (GTask        *task,
                   gpointer      source_object,
@@ -484,11 +339,10 @@ io_writeback_job (GTask        *task,
 	writeback_handlers = data->writeback_handlers;
 
 	while (writeback_handlers) {
-		handled |= tracker_writeback_update_metadata (writeback_handlers->data,
-		                                              data->results,
-		                                              data->connection,
-		                                              data->cancellable,
-		                                              (error) ? NULL : &error);
+		handled |= tracker_writeback_write_metadata (writeback_handlers->data,
+		                                             data->resource,
+		                                             data->cancellable,
+		                                             (error) ? NULL : &error);
 		writeback_handlers = writeback_handlers->next;
 	}
 
@@ -509,84 +363,104 @@ io_writeback_job (GTask        *task,
 	g_idle_add (perform_writeback_cb, data);
 }
 
+gboolean
+module_matches_resource (TrackerWritebackModule *module,
+                         GList                  *types)
+{
+	TrackerNamespaceManager *namespaces;
+	const gchar * const *module_types;
+	GList *l;
+
+	module_types = tracker_writeback_module_get_rdf_types (module);
+	namespaces = tracker_namespace_manager_get_default ();
+
+	for (l = types; l; l = l->next) {
+		GValue *value = l->data;
+		const gchar *type;
+
+		if (G_VALUE_HOLDS_STRING (value)) {
+			gchar *expanded;
+			gboolean match;
+
+			type = g_value_get_string (value);
+			expanded = tracker_namespace_manager_expand_uri (namespaces,
+			                                                 type);
+			match = g_strv_contains (module_types, expanded);
+			g_free (expanded);
+
+			if (match)
+				return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 static void
-handle_method_call_perform_writeback (TrackerController     *controller,
-                                      GDBusMethodInvocation *invocation,
-                                      GVariant              *parameters)
+handle_method_call_writeback (TrackerController     *controller,
+                              GDBusMethodInvocation *invocation,
+                              GVariant              *parameters)
 {
 	TrackerControllerPrivate *priv;
 	TrackerDBusRequest *request;
-	const gchar *subject;
-	GPtrArray *results = NULL;
+	TrackerResource *resource;
 	GHashTableIter iter;
 	gpointer key, value;
-	GVariantIter *iter1, *iter2, *iter3;
-	GArray *rdf_types_array;
-	GStrv rdf_types;
-	gchar *rdf_type = NULL;
 	GList *writeback_handlers = NULL;
+	GList *types;
 
 	priv = tracker_controller_get_instance_private (controller);
 
-	results = g_ptr_array_new_with_free_func ((GDestroyNotify) g_strfreev);
-	g_variant_get (parameters, "(&sasaas)", &subject, &iter1, &iter2);
-
-	rdf_types_array = g_array_new (TRUE, TRUE, sizeof (gchar *));
-	while (g_variant_iter_loop (iter1, "&s", &rdf_type)) {
-		g_array_append_val (rdf_types_array, rdf_type);
-	}
-
-	rdf_types = (GStrv) rdf_types_array->data;
-	g_array_free (rdf_types_array, FALSE);
-
-	while (g_variant_iter_loop (iter2, "as", &iter3)) {
-		GArray *row_array = g_array_new (TRUE, TRUE, sizeof (gchar *));
-		gchar *cell = NULL;
-
-		while (g_variant_iter_loop (iter3, "&s", &cell)) {
-			g_array_append_val (row_array, cell);
-		}
-
-		g_ptr_array_add (results, row_array->data);
-		g_array_free (row_array, FALSE);
-	}
-
-	g_variant_iter_free (iter1);
-	g_variant_iter_free (iter2);
-
 	reset_shutdown_timeout (controller);
-	request = tracker_dbus_request_begin (NULL, "%s (%s)", __FUNCTION__, subject);
+	request = tracker_dbus_request_begin (NULL, "%s", __FUNCTION__);
+
+	resource = tracker_resource_deserialize (g_variant_get_child_value (parameters, 0));
+	if (!resource) {
+		g_dbus_method_invocation_return_error (invocation,
+		                                       G_DBUS_ERROR,
+		                                       G_DBUS_ERROR_INVALID_ARGS,
+		                                       "GVariant does not serialize to a resource");
+		tracker_dbus_request_end (request, NULL);
+		return;
+	}
+
+	types = tracker_resource_get_values (resource, "rdf:type");
+	if (!types) {
+		g_dbus_method_invocation_return_error (invocation,
+		                                       G_DBUS_ERROR,
+		                                       G_DBUS_ERROR_INVALID_ARGS,
+		                                       "Resource does not define rdf:type");
+		tracker_dbus_request_end (request, NULL);
+		return;
+	}
 
 	g_hash_table_iter_init (&iter, priv->modules);
 
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		TrackerWritebackModule *module;
-		const gchar * const *module_types;
 
 		module = value;
-		module_types = tracker_writeback_module_get_rdf_types (module);
 
-		if (sparql_rdf_types_match (module_types, (const gchar * const *) rdf_types)) {
+		if (module_matches_resource (module, types)) {
 			TrackerWriteback *writeback;
 
-			g_message ("  Updating metadata for subject:'%s' using module:'%s'",
-			           subject,
-			           module->name);
+			g_debug ("Using module '%s' as a candidate",
+			         module->name);
 
 			writeback = tracker_writeback_module_create (module);
 			writeback_handlers = g_list_prepend (writeback_handlers, writeback);
 		}
 	}
 
+	g_list_free (types);
+
 	if (writeback_handlers != NULL) {
 		WritebackData *data;
 		GTask *task;
 
 		data = writeback_data_new (controller,
 		                           writeback_handlers,
-		                           priv->connection,
-		                           subject,
-		                           results,
+		                           resource,
 		                           invocation,
 		                           request);
 		task = g_task_new (controller, data->cancellable, NULL, NULL);
@@ -596,47 +470,14 @@ handle_method_call_perform_writeback (TrackerController     *controller,
 		g_task_run_in_thread (task, io_writeback_job);
 		g_object_unref (task);
 	} else {
-		char *rdf_types_string;
-		rdf_types_string = g_strjoinv (", ", rdf_types);
 		g_dbus_method_invocation_return_error (invocation,
 		                                       TRACKER_DBUS_ERROR,
 		                                       TRACKER_DBUS_ERROR_UNSUPPORTED,
-		                                       "None of %i writeback modules matched any of the "
-		                                       "given RDF types: %s",
-		                                       g_hash_table_size (priv->modules),
-		                                       rdf_types_string);
-		g_free (rdf_types_string);
+		                                       "Resource description does not match any writeback modules");
+		tracker_dbus_request_end (request, NULL);
 	}
 
-	g_free (rdf_types);
-}
-
-static void
-handle_method_call_cancel_tasks (TrackerController     *controller,
-                                 GDBusMethodInvocation *invocation,
-                                 GVariant              *parameters)
-{
-	TrackerDBusRequest *request;
-	gchar **subjects;
-	gint i;
-
-#ifdef THREAD_ENABLE_TRACE
-	g_debug ("Thread:%p (Controller) --> Got Tasks cancellation request",
-		 g_thread_self ());
-#endif /* THREAD_ENABLE_TRACE */
-
-
-	g_variant_get (parameters, "(^as)", &subjects);
-
-	request = tracker_dbus_request_begin (NULL, "%s (%s, ...)", __FUNCTION__, subjects[0]);
-
-	for (i = 0; subjects[i] != NULL; i++) {
-		cancel_tasks (controller, subjects[i], NULL);
-	}
-
-	g_strfreev (subjects);
-	tracker_dbus_request_end (request, NULL);
-	g_dbus_method_invocation_return_value (invocation, NULL);
+	g_object_unref (resource);
 }
 
 static void
@@ -651,12 +492,8 @@ handle_method_call (GDBusConnection       *connection,
 {
 	TrackerController *controller = user_data;
 
-	if (g_strcmp0 (method_name, "GetPid") == 0) {
-		handle_method_call_get_pid (controller, invocation, parameters);
-	} else if (g_strcmp0 (method_name, "PerformWriteback") == 0) {
-		handle_method_call_perform_writeback (controller, invocation, parameters);
-	} else if (g_strcmp0 (method_name, "CancelTasks") == 0) {
-		handle_method_call_cancel_tasks (controller, invocation, parameters);
+	if (g_strcmp0 (method_name, "Writeback") == 0) {
+		handle_method_call_writeback (controller, invocation, parameters);
 	} else {
 		g_warning ("Unknown method '%s' called", method_name);
 	}
@@ -727,14 +564,6 @@ tracker_controller_dbus_start (TrackerController   *controller,
 
 	priv = tracker_controller_get_instance_private (controller);
 
-	priv->connection = tracker_sparql_connection_bus_new ("org.freedesktop.Tracker3.Miner.Files",
-	                                                      NULL, NULL, &err);
-
-	if (!priv->connection) {
-		g_propagate_error (error, err);
-		return FALSE;
-	}
-
 	priv->d_connection = g_bus_get_sync (TRACKER_IPC_BUS, NULL, &err);
 
 	if (!priv->d_connection) {
@@ -809,10 +638,6 @@ tracker_controller_dbus_stop (TrackerController *controller)
 	if (priv->d_connection) {
 		g_object_unref (priv->d_connection);
 	}
-
-	if (priv->connection) {
-		g_object_unref (priv->connection);
-	}
 }
 
 TrackerController *
@@ -861,9 +686,7 @@ tracker_controller_thread_func (gpointer user_data)
 
 	g_object_unref (controller);
 
-	/* This is where we exit, be it
-	 * either through umount events on monitored
-	 * files' volumes or the timeout being reached
+	/* This is where we exit through the timeout being reached
 	 */
 	exit (0);
 	return NULL;
