@@ -45,6 +45,7 @@ TRACKER_EXTRACT_PATH = config['TRACKER_EXTRACT_PATH']
 def test_environment(tmpdir):
     return {
         'DCONF_PROFILE': config['TEST_DCONF_PROFILE'],
+        'GIO_MODULE_DIR': config['MOCK_VOLUME_MONITOR_DIR'],
         'TRACKER_TEST_DOMAIN_ONTOLOGY_RULE': config['TEST_DOMAIN_ONTOLOGY_RULE'],
         'TRACKER_EXTRACTOR_RULES_DIR': config['TEST_EXTRACTOR_RULES_DIR'],
         'TRACKER_EXTRACTORS_DIR': config['TEST_EXTRACTORS_DIR'],
@@ -66,6 +67,10 @@ def cli_subcommands_dir():
     return config['TEST_CLI_SUBCOMMANDS_DIR']
 
 
+def tap_protocol_enabled():
+    return config['TEST_TAP_ENABLED']
+
+
 def nepomuk_path():
     parser = configparser.ConfigParser()
     parser.read(config['TEST_DOMAIN_ONTOLOGY_RULE'])
