@@ -69,7 +69,18 @@ def tracker_test_main():
                             handlers=[handler_stderr, handler_stdout],
                             format='%(message)s')
 
-    ut.main(failfast=True, verbosity=2)
+    runner = None
+
+    if cfg.tap_protocol_enabled():
+        try:
+            from tap import TAPTestRunner
+            runner = TAPTestRunner()
+            runner.set_stream(True)
+        except ImportError as e:
+            log.error('No TAP test runner found: %s', e)
+            raise
+
+    ut.main(testRunner=runner, failfast=True, verbosity=2)
 
 
 class TrackerMinerTest(ut.TestCase):
@@ -92,9 +103,13 @@ class TrackerMinerTest(ut.TestCase):
         }
         return settings
 
-    def setUp(self):
+    def environment(self):
         extra_env = cfg.test_environment(self.workdir)
         extra_env['LANG'] = 'en_GB.utf8'
+        return extra_env
+
+    def setUp(self):
+        extra_env = self.environment()
 
         self.sandbox = trackertestutils.helpers.TrackerDBusSandbox(
             session_bus_config_file=cfg.TEST_DBUS_DAEMON_CONFIG_FILE, extra_env=extra_env)
@@ -139,7 +154,10 @@ class TrackerMinerTest(ut.TestCase):
             self.fail("Resource <%s> should not exist" % urn)
 
     def await_document_inserted(self, path, content=None):
-        """Wraps await_insert() context manager."""
+        """Wraps await_insert() context manager.
+
+        Use this if you are triggering insertion inside the context manager"""
+
         if isinstance(path, pathlib.Path):
             url = path.as_uri()
         else:
@@ -156,6 +174,36 @@ class TrackerMinerTest(ut.TestCase):
 
         return self.tracker.await_insert(DOCUMENTS_GRAPH, '; '.join(expected), timeout=cfg.AWAIT_TIMEOUT)
 
+    def ensure_document_inserted(self, path, content=None):
+        """Block until document is inserted.
+
+        Use this if insertion may already have happened."""
+
+        if isinstance(path, pathlib.Path):
+            url = path.as_uri()
+        else:
+            url = self.uri(path)
+
+        expected = [
+            'a nfo:Document',
+            f'nie:isStoredAs <{url}>',
+        ]
+
+        if content:
+            content_escaped = Tracker.sparql_escape_string(content)
+            expected += [f'nie:plainTextContent "{content_escaped}"']
+
+        return self.tracker.ensure_resource(DOCUMENTS_GRAPH, ';'.join(expected), timeout=cfg.AWAIT_TIMEOUT)
+
+    def await_insert_dir(self, path):
+        if isinstance(path, pathlib.Path):
+            url = path.as_uri()
+        else:
+            url = self.uri(path)
+
+        expected = f'nie:isStoredAs <{url}>'
+        return self.tracker.await_insert(FILESYSTEM_GRAPH, expected, timeout=cfg.AWAIT_TIMEOUT)
+
     def await_document_uri_change(self, resource_id, from_path, to_path):
         """Wraps await_update() context manager."""
         from_url = self.uri(from_path)
@@ -245,13 +293,70 @@ class TrackerMinerFTSTest (TrackerMinerTest):
         return int(result[0][0])
 
 
-def get_tracker_extract_jsonld_output(extra_env, filename, mime_type=None):
+class TrackerMinerRemovableMediaTest(TrackerMinerTest):
+    """
+    Fixture to test removable device handling in tracker-miner-fs.
+    """
+
+    MOCK_VOLUME_MONITOR_DBUS_NAME = 'org.freedesktop.Tracker3.MockVolumeMonitor'
+    MOCK_VOLUME_MONITOR_OBJECT_PATH = '/org/freedesktop/Tracker3/MockVolumeMonitor'
+    MOCK_VOLUME_MONITOR_IFACE = 'org.freedesktop.Tracker3.MockVolumeMonitor'
+
+    def config(self):
+        settings = super(TrackerMinerRemovableMediaTest, self).config()
+        settings['org.freedesktop.Tracker3.Miner.Files']['index-removable-devices'] = GLib.Variant.new_boolean(True)
+        return settings
+
+    def environment(self):
+        extra_env = super(TrackerMinerRemovableMediaTest, self).environment()
+        extra_env['GIO_USE_VOLUME_MONITOR'] = 'mockvolumemonitor'
+        return extra_env
+
+    def add_removable_device(self, path):
+        conn = self.sandbox.get_session_bus_connection()
+        timeout = cfg.AWAIT_TIMEOUT * 1000
+        cancellable = None
+        conn.call_sync(self.MOCK_VOLUME_MONITOR_DBUS_NAME,
+                       self.MOCK_VOLUME_MONITOR_OBJECT_PATH,
+                       self.MOCK_VOLUME_MONITOR_IFACE,
+                       'AddMount',
+                       GLib.Variant('(s)', [self.uri(path)]),
+                       None, Gio.DBusCallFlags.NONE,
+                       timeout, cancellable)
+
+    def remove_removable_device(self, path):
+        conn = self.sandbox.get_session_bus_connection()
+        timeout = cfg.AWAIT_TIMEOUT * 1000
+        cancellable = None
+        conn.call_sync(self.MOCK_VOLUME_MONITOR_DBUS_NAME,
+                       self.MOCK_VOLUME_MONITOR_OBJECT_PATH,
+                       self.MOCK_VOLUME_MONITOR_IFACE,
+                       'RemoveMount',
+                       GLib.Variant('(s)', [self.uri(path)]),
+                       None, Gio.DBusCallFlags.NONE,
+                       timeout, cancellable)
+
+    def await_device_removed(self, device_uri):
+        result = self.tracker.query("""
+            SELECT tracker:id(?u) {
+                <%s> a nfo:FileDataObject ;
+                    nie:interpretedAs/nie:rootElementOf ?u .
+            }""" % device_uri)
+        resource_id = int(result[0][0])
+        return self.tracker.await_property_update(
+            FILESYSTEM_GRAPH, resource_id,
+            "tracker:available true",
+            "tracker:available false")
+
+
+def get_tracker_extract_output(extra_env, filename, output_format='json-ld', mime_type=None):
     """
     Runs `tracker-extract --file` to extract metadata from a file.
     """
 
     tracker_extract = os.path.join(cfg.TRACKER_EXTRACT_PATH)
-    command = [tracker_extract, '--output-format=json-ld', '--file', str(filename)]
+    command = [tracker_extract, '--output-format', output_format, '--file',
+               str(filename)]
     if mime_type is not None:
         command.extend(['--mime', mime_type])
 
@@ -285,19 +390,20 @@ def get_tracker_extract_jsonld_output(extra_env, filename, mime_type=None):
         error_output = stderr.decode('utf-8').strip()
         log.debug("Error output from tracker-extract:\n%s", error_output)
 
-    try:
-        output = stdout.decode('utf-8')
+    output = stdout.decode('utf-8')
 
-        if len(output.strip()) == 0:
-            raise RuntimeError("tracker-extract didn't return any data.\n"
-                               "Error output was: %s" % error_output)
+    if len(output.strip()) == 0:
+        raise RuntimeError("tracker-extract didn't return any data.\n"
+                            "Error output was: %s" % error_output)
 
-        data = json.loads(output)
-    except ValueError as e:
-        raise RuntimeError("tracker-extract did not return valid JSON data: %s\n"
-                           "Output was: %s" % (e, output))
-
-    return data
+    if output_format == 'json-ld':
+        try:
+            return json.loads(output)
+        except ValueError as e:
+            raise RuntimeError("tracker-extract did not return valid JSON data: %s\n"
+                               "Output was: %s" % (e, output))
+    else:
+        return output
 
 
 class TrackerExtractTestCase(ut.TestCase):
@@ -326,7 +432,7 @@ class TrackerExtractTestCase(ut.TestCase):
         """
         Checks tracker-extract json-ld output against the expected result.
 
-        Use get_tracker_extract_jsonld_output() to get the extractor output.
+        Use get_tracker_extract_output() to get the extractor output.
 
         Look in test-extraction-data/*/*.expected.json for examples of the spec
         format.
@@ -393,6 +499,11 @@ class TrackerExtractTestCase(ut.TestCase):
         for prop in expected_keys:
             self.assertDictHasKey(result, prop,
                                   error_missing_prop % (prop, filename, spec_filename))
+            if isinstance(spec[prop], list):
+                for value in spec[prop]:
+                    self.assertIn(value, result[prop])
+            else:
+                self.assertIn(spec[prop], result[prop])
 
 
 TEST_FILE_JPEG = "writeback-test-1.jpeg"
